@@ -56,8 +56,9 @@ Parse::DNS::Zone does not support $GENERATE in this version.
 
 =cut
 
+use 5.010;
 package Parse::DNS::Zone;
-our $VERSION = '0.5';
+our $VERSION = '0.51';
 use warnings;
 use strict;
 use File::Basename;
@@ -589,7 +590,8 @@ RFC 1034, RFC 1035, Bind Administrator's Guide
 =head1 AVAILABILITY
 
 Latest stable version is available on CPAN. Current development
-version is available on https://github.com/olof/Parse-DNS-Zone.
+version is available on https://github.com/olof/Parse-DNS-Zone, and
+this is the I<preferred> place to report issues.
 
 =head1 COPYRIGHT
 
